@@ -26,7 +26,7 @@ LOG = logging.getLogger(__name__)
 
 API_VERSION_OPTION = 'os_baremetal_api_version'
 API_NAME = 'baremetal'
-LAST_KNOWN_API_VERSION = 33
+LAST_KNOWN_API_VERSION = 34
 API_VERSIONS = {
     '1.%d' % i: 'ironicclient.v1.client.Client'
     for i in range(1, LAST_KNOWN_API_VERSION + 1)
@@ -85,7 +85,9 @@ def build_option_parser(parser):
         help='Baremetal API version, default=' +
              http.DEFAULT_VER +
              ' (Env: OS_BAREMETAL_API_VERSION). '
-             '"latest" is the latest known API version',
+             'Use "latest" for the latest known API version. '
+             'The default value will change to "latest" in the Queens '
+             'release.',
     )
     return parser
 
