@@ -19,6 +19,9 @@ from __future__ import print_function
 import argparse
 import getpass
 import logging
+import os
+import pkgutil
+import re
 import sys
 
 from keystoneauth1.loading import session as kasession
@@ -27,6 +30,7 @@ from oslo_utils import importutils
 import six
 
 import ironicclient
+from ironicclient.common.apiclient import exceptions
 from ironicclient.common import cliutils
 from ironicclient.common import http
 from ironicclient.common.i18n import _
@@ -35,6 +39,13 @@ from ironicclient import exc
 
 
 LATEST_API_VERSION = ('1', 'latest')
+MISSING_VERSION_WARNING = (
+    "You are using the default API version of the 'ironic' command. "
+    "This is currently API version %s. In the future, the default will be "
+    "the latest API version understood by both API and CLI. You can preserve "
+    "the current behavior by passing the --ironic-api-version argument with "
+    "the desired version or using the IRONIC_API_VERSION environment variable."
+)
 
 
 class IronicShell(object):
@@ -149,11 +160,13 @@ class IronicShell(object):
                             help=argparse.SUPPRESS)
 
         parser.add_argument('--ironic-api-version',
-                            default=cliutils.env(
-                                'IRONIC_API_VERSION', default='1'),
+                            default=cliutils.env('IRONIC_API_VERSION',
+                                                 default=None),
                             help=_('Accepts 1.x (where "x" is microversion) '
-                                   'or "latest", Defaults to '
-                                   'env[IRONIC_API_VERSION] or 1'))
+                                   'or "latest". Defaults to '
+                                   'env[IRONIC_API_VERSION] or %s. Starting '
+                                   'with the Queens release this will '
+                                   'default to "latest".') % http.DEFAULT_VER)
 
         parser.add_argument('--ironic_api_version',
                             help=argparse.SUPPRESS)
@@ -235,14 +248,31 @@ class IronicShell(object):
 
         return parser
 
+    def get_available_major_versions(self):
+        matcher = re.compile(r"^v[0-9]+$")
+        submodules = pkgutil.iter_modules([os.path.dirname(__file__)])
+        available_versions = [name[1:] for loader, name, ispkg in submodules
+                              if matcher.search(name)]
+
+        return available_versions
+
     def get_subcommand_parser(self, version):
         parser = self.get_base_parser()
 
         self.subcommands = {}
         subparsers = parser.add_subparsers(metavar='<subcommand>',
                                            dest='subparser_name')
-        submodule = importutils.import_versioned_module('ironicclient',
-                                                        version, 'shell')
+        try:
+            submodule = importutils.import_versioned_module('ironicclient',
+                                                            version, 'shell')
+        except ImportError as e:
+            msg = _("Invalid client version '%(version)s'. "
+                    "Major part must be one of: '%(major)s'") % {
+                "version": version,
+                "major": ", ".join(self.get_available_major_versions())}
+            raise exceptions.UnsupportedVersion(
+                _('%(message)s, error was: %(error)s') %
+                {'message': msg, 'error': e})
         submodule.enhance_parser(parser, subparsers, self.subcommands)
         utils.define_commands_from_module(subparsers, self, self.subcommands)
         return parser
@@ -273,6 +303,11 @@ class IronicShell(object):
         if api_version == 'latest':
             return LATEST_API_VERSION
         else:
+            if api_version is None:
+                print(MISSING_VERSION_WARNING % http.DEFAULT_VER,
+                      file=sys.stderr)
+                api_version = '1'
+
             try:
                 versions = tuple(int(i) for i in api_version.split('.'))
             except ValueError:
